# Custom Extension Examples

The examples in the this directory all demonstrate how to add custom extensions
to Bokeh. There are some additional examples in other directories:

* app/surface3d
* models/file/latex_extension.py

More detailed documentation on creating custom extensions can be found here:

https://bokeh.pydata.org/en/latest/docs/user_guide/extensions.html
